@@ -531,7 +531,7 @@ class BaseInlineFormSetWithAddMoreButton(BaseInlineFormSet):
         empty_form_as_p = str(self.empty_form.as_p())
         div_name = str(self.prefix) + 'div'
 
-        forms_as_p = super().as_p()
+        forms_as_p = BaseInlineFormSet.as_p(self)
         p = f"""<div class="row" id="{div_name}">
         {forms_as_p}
         </div>
@@ -600,13 +600,13 @@ class DataTransform(forms.ModelForm):
 
         except Exception as e:
             print(str(e))
-            self.nested_data_transformer_form = dataTransformerInlineFormset(
-                instance=self.instance,
-                data=self.data if self.is_bound else None,
-                files=self.files if self.is_bound else None,
-                prefix=str(self.instance.id) + 'dataTransformerInlineFormset'
-            )
-            self.nested_data_transformer_form.extra = 0
+            # self.nested_data_transformer_form = dataTransformerInlineFormset(
+            #     instance=self.instance,
+            #     data=self.data if self.is_bound else None,
+            #     files=self.files if self.is_bound else None,
+            #     prefix=str(self.instance.id) + 'dataTransformerInlineFormset'
+            # )
+            # self.nested_data_transformer_form.extra = 0
 
         self.nested_constants_form = DataConstantsTransformerInlineFormset(
             instance=self.instance,
