@@ -438,6 +438,11 @@ class AccessoryViewSet(viewsets.ModelViewSet):
         # request should be ajax and method should be POST.
         form = DataTransformRoot(instance=DataTransformer.objects.get(pk=request.POST['id']),
                              data=request.POST)
+        if form.is_valid():
+            form.save(True)
+        else:
+            print(form.errors)
+
         data_transformer_root = form.save()
         data_transformer_family = data_transformer_root.get_family()
         children_dict = defaultdict(list)
